@@ -24,6 +24,8 @@ contMap<-function(tree,x,res=100,fsize=NULL,ftype=NULL,lwd=4,legend=NULL,lims=NU
 		tree$maps[[i]]<-XX[,2]-XX[,1]
 		names(tree$maps[[i]])<-d
 	}
+	tree$mapped.edge<-makeMappedEdge(tree$edge,tree$maps)
+	tree$mapped.edge<-tree$mapped.edge[,order(as.numeric(colnames(tree$mapped.edge)))]
 	xx<-list(tree=tree,cols=cols,lims=lims)
 	class(xx)<-"contMap"
 	if(plot) plot.contMap(xx,fsize=fsize,ftype=ftype,lwd=lwd,legend=legend,outline=outline,sig=sig,type=type,mar=mar)
