@@ -44,6 +44,8 @@ densityMap<-function(trees,res=100,fsize=NULL,ftype=NULL,lwd=3,check=FALSE,legen
 		names(tree$maps[[i]])<-round(ZZ*1000)
 	}
 	cols<-rainbow(1001,start=0.7,end=0); names(cols)<-0:1000
+	tree$mapped.edge<-makeMappedEdge(tree$edge,tree$maps)
+	tree$mapped.edge<-tree$mapped.edge[,order(as.numeric(colnames(tree$mapped.edge)))]
 	x<-list(tree=tree,cols=cols); class(x)<-"densityMap"
 	if(plot) plot.densityMap(x,fsize=fsize,ftype=ftype,lwd=lwd,legend=legend,outline=outline,type=type,mar=mar)
 	invisible(x)
