@@ -1,6 +1,56 @@
 # some utility functions
 # written by Liam J. Revell 2011, 2012, 2013
 
+# function to merge mapped states
+# written by Liam J. Revell 2013
+mergeMappedStates<-function(tree,old.states,new.state){
+	if(class(tree)=="multiPhylo"){
+		tree<-unclass(tree)
+		tree<-lapply(tree,mergeMappedStates,old.states=old.states,new.state=new.state)
+		class(tree)<-"multiPhylo"
+	} else {
+		maps<-tree$maps
+		rr<-function(map,oo,nn){ 
+			for(i in 1:length(map)) if(names(map)[i]%in%oo) names(map)[i]<-nn
+			map
+		}
+		mm<-function(map){
+			if(length(map)>1){
+				new.map<-vector()
+				j<-1
+				new.map[j]<-map[1]
+				names(new.map)[j]<-names(map)[1]
+				for(i in 2:length(map)){
+					if(names(map)[i]==names(map)[i-1]){ 
+						new.map[j]<-map[i]+new.map[j]
+						names(new.map)[j]<-names(map)[i]
+					} else {
+						j<-j+1
+						new.map[j]<-map[i]
+						names(new.map)[j]<-names(map)[i]
+					}
+				}
+				map<-new.map
+			}
+			map
+		}
+		maps<-lapply(maps,rr,oo=old.states,nn=new.state)
+		if(length(old.states)>1){ 
+			maps<-lapply(maps,mm)
+			mapped.edge<-tree$mapped.edge
+			mapped.edge<-cbind(rowSums(mapped.edge[,colnames(mapped.edge)%in%old.states]),
+				mapped.edge[,setdiff(colnames(mapped.edge),old.states)])
+			colnames(mapped.edge)<-c(new.state,setdiff(colnames(tree$mapped.edge),old.states))
+		} else {
+			mapped.edge<-tree$mapped.edge
+			colnames(mapped.edge)[which(colnames(mapped.edge)==old.states)]<-new.state
+		}
+		tree$maps<-maps
+		tree$mapped.edge<-mapped.edge
+	}
+	return(tree)
+}
+
 # function rotates a node or multiple nodes
 # written by Liam J. Revell 2013
 rotateNodes<-function(tree,nodes,polytom=c(1,2),...){
@@ -150,51 +200,6 @@ getCladesofSize<-function(tree,clade.size=2){
 	return(trees)
 }
 
-# function to merge mapped states
-# written by Liam J. Revell 2013
-mergeMappedStates<-function(tree,old.states,new.state){
-	if(class(tree)=="multiPhylo"){
-		tree<-unclass(tree)
-		tree<-lapply(tree,mergeMappedStates,old.states=old.states,new.state=new.state)
-		class(tree)<-"multiPhylo"
-	} else {
-		maps<-tree$maps
-		rr<-function(map,oo,nn){ 
-			for(i in 1:length(map)) if(names(map)[i]%in%oo) names(map)[i]<-nn
-			map
-		}
-		mm<-function(map){
-			if(length(map)>1){
-				new.map<-vector()
-				j<-1
-				new.map[j]<-map[1]
-				names(new.map)[j]<-names(map)[1]
-				for(i in 2:length(map)){
-					if(names(map)[i]==names(map)[i-1]){ 
-						new.map[j]<-map[i]+new.map[j]
-						names(new.map)[j]<-names(map)[i]
-					} else {
-						j<-j+1
-						new.map[j]<-map[i]
-						names(new.map)[j]<-names(map)[i]
-					}
-				}
-				map<-new.map
-			}
-			map
-		}
-		maps<-lapply(maps,rr,oo=old.states,nn=new.state)
-		maps<-lapply(maps,mm)
-		mapped.edge<-tree$mapped.edge
-		mapped.edge<-cbind(rowSums(mapped.edge[,colnames(mapped.edge)%in%old.states]),
-			mapped.edge[,setdiff(colnames(mapped.edge),old.states)])
-		colnames(mapped.edge)<-c(new.state,setdiff(colnames(tree$mapped.edge),old.states))
-		tree$maps<-maps
-		tree$mapped.edge<-mapped.edge
-	}
-	return(tree)
-}
-
 # function to rescale simmap style trees
 # written by Liam J. Revell 2012, 2013
 rescaleSimmap<-function(tree,totalDepth=1.0){
